Common functions for Python / Vue / Eel project.

[![Python versions](https://img.shields.io/pypi/pyversions/pyvueeel.svg)](https://pypi.python.org/pypi/pyvueeel/) [![PyPI version](https://badge.fury.io/py/pyvueeel.svg)](https://badge.fury.io/py/pyvueeel) [![Downloads](https://pepy.tech/badge/pyvueeel)](https://pepy.tech/project/pyvueeel) [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Malachov/pyvueeel.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Malachov/pyvueeel/context:python) [![Documentation Status](https://readthedocs.org/projects/pyvueeel/badge/?version=latest)](https://pyvueeel.readthedocs.io/en/latest/?badge=latest) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![codecov](https://codecov.io/gh/Malachov/pyvueeel/branch/master/graph/badge.svg)](https://codecov.io/gh/Malachov/pyvueeel)

It contains functions for running eel, overriding eel.expose decorator, converting json to correct python format or transform data into form for vue tables and plots.

Try [cookiecutter template](https://github.com/Malachov/project-starter-cookiecutter) for working examples.

Image of such an app

<div align="center"><img src="docs/source/_static/project-starter-gui.png" width="620" alt="project-starter-gui"/></div>

## Links

Official documentation - [readthedocs](https://pyvueeel.readthedocs.io/)

Official repo - [GitHub](https://github.com/Malachov/pyvueeel)


## Installation

Python >=3.6 (Python 2 is not supported).

Install with

```console
pip install pyvueeel
```